.. _utilipy-code_quality:

============
Code Quality
============

.. container::

	|Codacy Quality| |Codacy Maintainability| |Code style: black|


.. |Code style: black| image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/psf/black

.. |Codacy Quality| image:: https://api.codacy.com/project/badge/Grade/c56175a35d0040e28cf3ff070271b9b3
	:target: https://www.codacy.com/manual/nstarman/utilipy
	:alt: Codacy Code Quality

.. |Codacy Maintainability| image:: https://api.codeclimate.com/v1/badges/102775da549e5999e4fc/maintainability
   :target: https://codeclimate.com/github/nstarman/utilipy/maintainability
   :alt: Maintainability
